@@ -1,3 +1,18 @@
+## Copyright (C) 2005-2012 Etienne Grossmann <etienne@egdn.net>
+##
+## This program is free software; you can redistribute it and/or modify it under
+## the terms of the GNU General Public License as published by the Free Software
+## Foundation; either version 3 of the License, or (at your option) any later
+## version.
+##
+## This program is distributed in the hope that it will be useful, but WITHOUT
+## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+## FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
+## details.
+##
+## You should have received a copy of the GNU General Public License along with
+## this program; if not, see <http://www.gnu.org/licenses/>.
+
 ##  s = vrml_DirectionalLight (...)   - Vrml DirectionalLight node
 ##
 ##  s is a string of the form :
@@ -19,11 +34,10 @@
 function s = vrml_DirectionalLight (varargin) # pos 2.1.39
 
 
-hash = struct ();		# pos 2.1.39
-
-
-if nargin, hash = setfield(hash,varargin{:}); end # pos 2.1.39
-## hash = rmfield (hash, "dummy");
+hash = struct ();
+for k=1:2:nargin,
+   hash = setfield(hash,varargin{k:k+1}); 
+end
 
 tpl = struct ("ambientIntensity", "%8.3f",\
 	      "intensity",        "%8.3f",\
@@ -37,7 +51,7 @@ for [val,key] = hash,
   if !(isnumeric(val) && isnan (val)),
 
 				# Check validity of field
-    if ! struct_contains (tpl, key)
+    if !isfield (tpl, key)
       error (sprintf ("vrml_PointLight : unknown field '%s'",key));
     end
 
